==> manaplus_1.3.10.27.2.orig.tar.xz: manaplus-1.3.10.27/src/net/ea/gui/guildtab.h <==
/*
 *  The ManaPlus Client
 *  Copyright (C) 2009  The Mana World Development Team
 *  Copyright (C) 2009-2010  The Mana Developers
 *  Copyright (C) 2011-2013  The ManaPlus Developers
 *
 *  This file is part of The ManaPlus Client.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef NET_EA_GUI_GUILDTAB_H
#define NET_EA_GUI_GUILDTAB_H

#include "gui/widgets/tabs/chattab.h"

namespace Ea
{

/**
 * A tab for a guild chat channel.
 */
class GuildTab : public ChatTab, public ConfigListener
{
    public:
        explicit GuildTab(const Widget2 *const widget);

        A_DELETE_COPY(GuildTab)

        virtual ~GuildTab();

        bool handleCommand(const std::string &type,
                           const std::string &args) override final;

        void showHelp() override;

        void saveToLogFile(const std::string &msg) const override final;

        int getType() const override final A_WARN_UNUSED
        { return ChatTab::TAB_GUILD; }

        void playNewMessageSound() const override final;

        void optionChanged(const std::string &value) override final;

    protected:
        void handleInput(const std::string &msg) override final;

        void getAutoCompleteList(StringVect &names) const override final;
};

}  // namespace Ea

#endif  // NET_EA_GUI_GUILDTAB_H

==> manaplus_1.4.1.18.orig.tar.xz: manaplus-1.4.1.18/src/net/ea/gui/guildtab.h <==
/*
 *  The ManaPlus Client
 *  Copyright (C) 2009  The Mana World Development Team
 *  Copyright (C) 2009-2010  The Mana Developers
 *  Copyright (C) 2011-2014  The ManaPlus Developers
 *
 *  This file is part of The ManaPlus Client.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef NET_EA_GUI_GUILDTAB_H
#define NET_EA_GUI_GUILDTAB_H

#include "gui/widgets/tabs/chattab.h"

namespace Ea
{

/**
 * A tab for a guild chat channel.
 */
class GuildTab : public ChatTab, public ConfigListener
{
    public:
        explicit GuildTab(const Widget2 *const widget);

        A_DELETE_COPY(GuildTab)

        virtual ~GuildTab();

        bool handleCommand(const std::string &restrict type,
                           const std::string &restrict args) override final;

        void showHelp() override;

        void saveToLogFile(const std::string &msg) const override final;

        int getType() const override final A_WARN_UNUSED
        { return ChatTab::TAB_GUILD; }

        void playNewMessageSound() const override final;

        void optionChanged(const std::string &value) override final;

    protected:
        void handleInput(const std::string &msg) override final;

        void getAutoCompleteList(StringVect &names) const override final;
};

}  // namespace Ea

#endif  // NET_EA_GUI_GUILDTAB_H
